<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl"
    xmlns:hl7="urn:hl7-org:v3"
    exclude-result-prefixes="xs xd hl7"
    version="2.0">
    <xd:doc scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Created on:</xd:b> Nov 20, 2012</xd:p>
            <xd:p><xd:b>Author:</xd:b> ahenket</xd:p>
            <xd:p>Feed QURX_IN990013NL (batched or as-is) and get QURX_IN990113NL</xd:p>
            <xd:p>Feed QURX_IN990113NL (batched or as-is) and get QURX_IN990013NL</xd:p>
        </xd:desc>
    </xd:doc>
    
    <xsl:output indent="yes"/>
    
    <!-- Cache first QURX_IN990013NL Patient and assume this is the same patient throughout -->
    <xsl:variable name="QURX_IN990013NL-Patient" select="/hl7:QURX_IN990013NL/hl7:ControlActProcess[1]/hl7:subject[1]/hl7:MedicationDispenseEvent[1]/hl7:product[1]/hl7:dispensedMedication[1]/hl7:directTargetOf[1]/hl7:prescription[1]/hl7:subject[1]/hl7:Patient[1]"/>
    <!-- Cache first QURX_IN990113NL Patient and assume this is the same patient throughout -->
    <xsl:variable name="QURX_IN990113NL-Patient" select="/hl7:QURX_IN990113NL/hl7:ControlActProcess[1]/hl7:subject[1]/hl7:MedicationDispenseList[1]/hl7:subject[1]/hl7:Patient[1]"/>
    
    <xsl:template match="/">
        <xsl:apply-templates select="node()"/>
    </xsl:template>
    
    <xsl:template match="hl7:QURX_IN990013NL">
        <QURX_IN990113NL xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="urn:hl7-org:v3 ../schemas/QURX_IN990113NL.xsd" xmlns="urn:hl7-org:v3">
            <xsl:apply-templates select="node()"/>
        </QURX_IN990113NL>
    </xsl:template>
    
    <xsl:template match="hl7:QURX_IN990013NL/hl7:interactionId">
        <interactionId xmlns="urn:hl7-org:v3" extension="QURX_IN990113NL" root="{@root}"/>
    </xsl:template>
    
    <xsl:template match="hl7:QURX_IN990113NL">
        <QURX_IN990013NL xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="urn:hl7-org:v3 ../schemas/QURX_IN990013NL.xsd" xmlns="urn:hl7-org:v3">
            <xsl:apply-templates select="node()"/>
        </QURX_IN990013NL>
    </xsl:template>
    
    <xsl:template match="hl7:QURX_IN990113NL/hl7:interactionId">
        <interactionId xmlns="urn:hl7-org:v3" extension="QURX_IN990013NL" root="{@root}"/>
    </xsl:template>
    
    <xsl:template match="hl7:QURX_IN990013NL/hl7:ControlActProcess">
        <xsl:variable name="resultCurrentQuantity" select="if (hl7:subject/hl7:MedicationDispenseEvent) then (1) else (0)"/>
        
        <xsl:copy copy-namespaces="no">
            <xsl:copy-of select="@*" copy-namespaces="yes"/>
            <!-- Use authorOrPerformer because that is mandatory -->
            <xsl:copy-of select="node() except node()[preceding-sibling::hl7:authorOrPerformer]" copy-namespaces="no"/>
            <!-- Should not be in this interaction, but doesn't hurt copying if it is -->
            <xsl:copy-of select="hl7:overseer" copy-namespaces="no"/>
            <xsl:if test="hl7:subject/hl7:MedicationDispenseEvent">
                <subject xmlns="urn:hl7-org:v3">
                    <MedicationDispenseList>
                        <code codeSystem="2.16.840.1.113883.5.4" code="MEDLIST"/>
                        <subject>
                            <xsl:copy-of select="$QURX_IN990013NL-Patient" copy-namespaces="no"/>
                        </subject>
                        <xsl:for-each select="hl7:subject/hl7:MedicationDispenseEvent">
                            <component>
                                <medicationDispenseEvent>
                                    <xsl:apply-templates select="node()"/>
                                </medicationDispenseEvent>
                            </component>
                        </xsl:for-each>
                    </MedicationDispenseList>
                </subject>
            </xsl:if>
            <xsl:copy-of select="hl7:reasonOf" copy-namespaces="no"/>
            <xsl:apply-templates select="hl7:queryAck">
                <xsl:with-param name="resultCurrentQuantity" select="$resultCurrentQuantity"/>
            </xsl:apply-templates>
            <xsl:copy-of select="hl7:queryByParameter" copy-namespaces="no"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="hl7:QURX_IN990113NL/hl7:ControlActProcess">
        <xsl:variable name="resultCurrentQuantity" select="count(hl7:subject) * count(hl7:subject/hl7:MedicationDispenseList/hl7:component)"/>
        
        <xsl:copy copy-namespaces="no">
            <xsl:copy-of select="@*" copy-namespaces="yes"/>
            <!-- Use authorOrPerformer because that is mandatory -->
            <xsl:copy-of select="node() except node()[preceding-sibling::hl7:authorOrPerformer]" copy-namespaces="no"/>
            <!-- Should not be in this interaction, but doesn't hurt copying if it is -->
            <xsl:copy-of select="hl7:overseer" copy-namespaces="no"/>
            <xsl:for-each select="hl7:subject">
                <xsl:for-each select="hl7:MedicationDispenseList/hl7:component/hl7:medicationDispenseEvent">
                    <subject xmlns="urn:hl7-org:v3">
                        <MedicationDispenseEvent xmlns="urn:hl7-org:v3">
                            <xsl:copy-of select="@*" copy-namespaces="yes"/>
                            <xsl:apply-templates select="node()"/>
                        </MedicationDispenseEvent>
                    </subject>
                </xsl:for-each>
            </xsl:for-each>
            <xsl:copy-of select="hl7:reasonOf" copy-namespaces="no"/>
            <xsl:apply-templates select="hl7:queryAck">
                <xsl:with-param name="resultCurrentQuantity" select="$resultCurrentQuantity"/>
            </xsl:apply-templates>
            <xsl:copy-of select="hl7:queryByParameter" copy-namespaces="no"/>
        </xsl:copy>
    </xsl:template>
    
    <!-- Applicable to QURX_IN990013NL -->
    <xsl:template match="hl7:prescription[not(ancestor::hl7:MedicationDispenseList)]">
        <xsl:copy copy-namespaces="no">
            <xsl:copy-of select="@*" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:id" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:text" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:statusCode" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:confidentialityCode" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:author" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:reason" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:reference" copy-namespaces="yes"/>
        </xsl:copy>
    </xsl:template>
    
    <!-- Applicable to QURX_IN990113NL -->
    <xsl:template match="hl7:prescription[ancestor::hl7:MedicationDispenseList]">
        <xsl:copy copy-namespaces="no">
            <xsl:copy-of select="@*" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:id" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:text" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:statusCode" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:confidentialityCode" copy-namespaces="yes"/>
            <subject xmlns="urn:hl7-org:v3">
                <xsl:copy-of select="$QURX_IN990113NL-Patient" copy-namespaces="no"/>
            </subject>
            <xsl:copy-of select="hl7:author" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:reason" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:reference" copy-namespaces="yes"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="hl7:queryAck">
        <xsl:param name="resultCurrentQuantity"/>
        
        <xsl:copy copy-namespaces="no">
            <xsl:copy-of select="@*" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:queryId" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:statusCode" copy-namespaces="yes"/>
            <xsl:copy-of select="hl7:queryResponseCode" copy-namespaces="yes"/>
            <resultTotalQuantity xmlns="urn:hl7-org:v3">
                <xsl:choose>
                    <xsl:when test="hl7:resultTotalQuantity[@value]">
                        <xsl:attribute name="value" select="$resultCurrentQuantity"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:attribute name="nullFlavor" select="hl7:resultTotalQuantity/@nullFlavor"/>
                    </xsl:otherwise>
                </xsl:choose>
            </resultTotalQuantity>
            <resultCurrentQuantity xmlns="urn:hl7-org:v3">
                <xsl:choose>
                    <xsl:when test="hl7:resultTotalQuantity[@value]">
                        <xsl:attribute name="value" select="$resultCurrentQuantity"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:attribute name="nullFlavor" select="hl7:resultTotalQuantity/@nullFlavor"/>
                    </xsl:otherwise>
                </xsl:choose>
            </resultCurrentQuantity>
            <xsl:copy-of select="hl7:resultRemainingQuantity" copy-namespaces="yes"/>
        </xsl:copy>
    </xsl:template>
    
    <xsl:template match="comment()">
        <xsl:choose>
            <xsl:when test="ancestor::hl7:QURX_IN990113NL or /hl7:QURX_IN990113NL">
                <xsl:comment><xsl:value-of select="replace(.,'QURX_IN990113NL','QURX_IN990013NL')"/></xsl:comment>
            </xsl:when>
            <xsl:when test="ancestor::hl7:QURX_IN990013NL or /hl7:QURX_IN990013NL">
                <xsl:comment><xsl:value-of select="replace(.,'QURX_IN990013NL','QURX_IN990113NL')"/></xsl:comment>
            </xsl:when>
            <xsl:otherwise>
                <xsl:copy-of select="self::node()" copy-namespaces="no"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="processing-instruction()">
        <xsl:choose>
            <xsl:when test="ancestor::hl7:QURX_IN990113NL or /hl7:QURX_IN990113NL">
                <xsl:processing-instruction name="{name()}" select="replace(.,'QURX_IN990113NL','QURX_IN990013NL')"/>
            </xsl:when>
            <xsl:when test="ancestor::hl7:QURX_IN990013NL or /hl7:QURX_IN990013NL">
                <xsl:processing-instruction name="{name()}" select="replace(.,'QURX_IN990013NL','QURX_IN990113NL')"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:copy-of select="self::node()" copy-namespaces="no"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xsl:template match="text()">
        <xsl:copy-of select="self::node()" copy-namespaces="no"/>
    </xsl:template>
    
    <xsl:template match="*">
        <xsl:copy copy-namespaces="no">
            <xsl:copy-of select="@*" copy-namespaces="yes"/>
            <xsl:apply-templates select="node()"/>
        </xsl:copy>
    </xsl:template>
</xsl:stylesheet>